@@ -36,7 +36,7 @@ class Gradle(PackageManager):
         sheet_list = []
 
         for d in json_data['dependencies']:
-
+            comment = ''
             used_filename = False
             group_id = ""
             artifact_id = ""
@@ -51,6 +51,10 @@ class Gradle(PackageManager):
                 oss_name, oss_ini_version = parse_oss_name_version_in_filename(filename)
                 used_filename = True
 
+            if self.total_dep_list:
+                if oss_name not in self.total_dep_list:
+                    continue
+
             oss_version = version_refine(oss_ini_version)
 
             license_names = []
@@ -65,13 +69,18 @@ class Gradle(PackageManager):
             if used_filename or group_id == "":
                 dn_loc = 'Unknown'
                 homepage = ''
-
             else:
                 dn_loc = f"{self.dn_url}{group_id}/{artifact_id}/{oss_ini_version}"
                 homepage = f"{self.dn_url}{group_id}/{artifact_id}"
 
+            if self.direct_dep:
+                if oss_name in self.direct_dep_list:
+                    comment = 'direct'
+                else:
+                    comment = 'transitive'
+
             sheet_list.append([const.SUPPORT_PACKAE.get(self.package_manager_name),
-                              oss_name, oss_version, license_name, dn_loc, homepage, '', '', ''])
+                              oss_name, oss_version, license_name, dn_loc, homepage, '', '', comment])
 
         return sheet_list
 
